@@ -13,12 +13,12 @@ NULL
 ##' @noRd
 .lotri1 <- function(x2, x3, env) {
   env$netas <- length(x3) - 1
-  .num <- sqrt(1 + env$netas * 8) / 2 - 1/2
+  .num <- sqrt(1 + env$netas * 8) / 2 - 1 / 2
   if (round(.num) == .num) {
     .n <- unlist(strsplit(as.character(x2), " +[+] +"))
     .n <- .n[.n != "+"]
     if (length(.n) == .num) {
-      env$names  <- c(env$names, .n)
+      env$names <- c(env$names, .n)
       .r <- x3[-1]
       .r <- unlist(lapply(.r, function(x) {
         return(as.numeric(eval(x)))
@@ -29,24 +29,120 @@ NULL
         .v <- .r[.k]
         .i <- .i + 1
         if (.i == .j) {
-          env$df  <- rbind(env$df,
-                           data.frame(i=env$eta1+.i, j=env$eta1+.i, x=.v))
+          env$df <- rbind(
+            env$df,
+            data.frame(i = env$eta1 + .i, j = env$eta1 + .i, x = .v)
+          )
           .j <- .j + 1
           .i <- 0
         } else {
-          env$df  <- rbind(env$df,
-                           data.frame(i=c(env$eta1+.i, env$eta1+.j),
-                                      j=c(env$eta1+.j, env$eta1+.i), x=.v))
+          env$df <- rbind(
+            env$df,
+            data.frame(
+              i = c(env$eta1 + .i, env$eta1 + .j),
+              j = c(env$eta1 + .j, env$eta1 + .i), x = .v
+            )
+          )
         }
       }
       env$eta1 <- env$eta1 + .num
-    }  else {
-      stop("number of items and lower triangular matrix mismatch")
+    } else {
+      stop("number of items and lower triangular matrix mismatch", call. = FALSE)
     }
   } else {
-    stop("matrix expression should be 'name ~ c(lower-tri)'")
+    stop("matrix expression should be 'name ~ c(lower-tri)'", call. = FALSE)
   }
+}
 
+.fcallTildeLhsSum <- function(x, env) {
+  ## et1+et2+et3~NULL lower triangular matrix
+  ## Should fixed be allowed????
+  if (any(tolower(as.character(x[[3]][[1]])) == c("c", "fix", "fixed"))) {
+    if (any(tolower(as.character(x[[3]][[1]])) == c("fix", "fixed"))) {
+      stop("fix/fixed are not allowed with lotri matrix specifications", call. = FALSE)
+    }
+    .lotri1(x[[2]], x[[3]], env)
+  } else {
+    .val <- try(eval(x[[3]]), silent = TRUE)
+    if (is.numeric(.val) || is.integer(.val)) {
+      env$netas <- 1
+      env$eta1 <- env$eta1 + 1
+      env$names <- c(env$names, as.character(x[[2]]))
+      env$df <- rbind(
+        env$df,
+        data.frame(i = env$eta1, j = env$eta1, x = .val)
+      )
+    } else {
+      .cnd <- try(as.character(x[[3]][[1]]), silent = TRUE)
+      .didCnd <- FALSE
+      if (inherits(.cnd, "character")) {
+        if (.cnd == "|") {
+          .cnd <- x[[3]][[3]]
+          .cndFull <- .parseCondition(.cnd, envir = env)
+          .cnd <- .cndFull[[1]]
+          ## Each condition is parsed so this new environment
+          ## should not be elsewhere
+          .env2 <- new.env(parent = emptyenv())
+          .env2$df <- NULL
+          .env2$eta1 <- 0L
+          env$cnd <- unique(c(env$cnd, .cnd))
+          env[[.cnd]] <- .env2
+          env[[paste0(.cnd, ".extra")]] <- .cndFull[[2]]
+          .val <- try(eval(x[[3]][[2]]), silent = TRUE)
+          if ((length(.val) == 1) &&
+                (is.numeric(.val) || is.integer(.val))) {
+            .env2$netas <- 1
+            .env2$eta1 <- .env2$eta1 + 1
+            .env2$names <- c(.env2$names, as.character(x[[2]]))
+            .env2$df <- rbind(
+              .env2$df,
+              data.frame(
+                i = .env2$eta1, j = .env2$eta1,
+                x = .val
+              )
+            )
+          } else {
+            .lotri1(x[[2]], x[[3]][[2]], .env2)
+          }
+          .didCnd <- TRUE
+        }
+      }
+      if (!.didCnd) {
+        stop("matrix expression should be 'name ~ c(lower-tri)'", call. = FALSE)
+      }
+    }
+  }
+}
+
+.fCallTilde <- function(x, env) {
+  if (length(x[[3]]) == 1) {
+    ## et1 ~ 0.2
+    env$netas <- 1
+    env$eta1 <- env$eta1 + 1
+    env$names <- c(env$names, as.character(x[[2]]))
+    env$df <- rbind(
+      env$df,
+      data.frame(
+        i = env$eta1,
+        j = env$eta1,
+        x = as.numeric(eval(x[[3]]))
+      )
+    )
+  } else {
+    .fcallTildeLhsSum(x, env)
+  }
+}
+
+.fCall <- function(x, env) {
+  if (identical(x[[1]], quote(`~`))) {
+    .fCallTilde(x, env)
+  } else if (identical(x[[1]], quote(`{`))) {
+    lapply(x, .f, env = env)
+  } else if (identical(x[[1]], quote(`quote`))) {
+    lapply(x[[2]], .f, env = env)
+  } else {
+    stop("matrix expression should be 'name ~ c(lower-tri)'", call. = FALSE)
+  }
 }
 
 ##' DSL parsing function
@@ -56,111 +152,42 @@ NULL
 ##' @return Nothing
 ##' @author Matthew Fidler
 ##' @noRd
-.f  <- function(x, env) {
+.f <- function(x, env) {
   if (is.name(x)) {
     return(character())
   } else if (is.call(x)) {
-    if (identical(x[[1]], quote(`~`))) {
-      if (length(x[[3]]) == 1) {
-        ## et1 ~ 0.2
-        env$netas <- 1
-        env$eta1 <- env$eta1 + 1
-        env$names  <- c(env$names, as.character(x[[2]]))
-        env$df  <- rbind(env$df,
-                         data.frame(i=env$eta1,
-                                    j=env$eta1,
-                                    x=as.numeric(eval(x[[3]]))))
-      } else {
-        ## et1+et2+et3~c() lower triangular matrix
-        ## Should fixed be allowed????
-        if (any(tolower(as.character(x[[3]][[1]])) == c("c", "fix", "fixed"))) {
-          if (any(tolower(as.character(x[[3]][[1]])) == c("fix", "fixed"))){
-            stop("fix/fixed are not allowed with lotri matrix specifications")
-          }
-          .lotri1(x[[2]], x[[3]], env)
-        } else {
-          .val <- try(eval(x[[3]]), silent=TRUE)
-          if (is.numeric(.val) || is.integer(.val)) {
-            env$netas <- 1
-            env$eta1 <- env$eta1 + 1
-            env$names  <- c(env$names, as.character(x[[2]]))
-            env$df  <- rbind(env$df,
-                             data.frame(i=env$eta1, j=env$eta1, x=.val))
-          } else {
-            .cnd <- try(as.character(x[[3]][[1]]), silent=TRUE)
-            .didCnd <- FALSE
-            if (inherits(.cnd, "character")) {
-              if (.cnd == "|") {
-                .cnd <- x[[3]][[3]]
-                .cndFull <- .parseCondition(.cnd, envir=env)
-                .cnd <- .cndFull[[1]]
-                ## Each condition is parsed so this new environment
-                ## should not be elsewhere
-                .env2  <- new.env(parent=emptyenv())
-                .env2$df  <- NULL
-                .env2$eta1 <- 0L
-                env$cnd <- unique(c(env$cnd, .cnd))
-                env[[.cnd]] <- .env2
-                env[[paste0(.cnd, ".extra")]] <- .cndFull[[2]]
-                .val <- try(eval(x[[3]][[2]]), silent=TRUE)
-                if ((length(.val) == 1) &&
-                    (is.numeric(.val) || is.integer(.val))) {
-                  .env2$netas <- 1
-                  .env2$eta1 <- .env2$eta1 + 1
-                  .env2$names  <- c(.env2$names, as.character(x[[2]]))
-                  .env2$df  <- rbind(.env2$df,
-                                     data.frame(i=.env2$eta1, j=.env2$eta1,
-                                                x=.val))
-                } else {
-                  .lotri1(x[[2]], x[[3]][[2]], .env2)
-                }
-                .didCnd <- TRUE
-              }
-            }
-            if (!.didCnd) {
-              stop("matrix expression should be 'name ~ c(lower-tri)'")
-            }
-          }
-        }
-      }
-    } else if (identical(x[[1]], quote(`{`))) {
-      lapply(x, .f, env=env)
-    } else if (identical(x[[1]], quote(`quote`))) {
-      lapply(x[[2]], .f, env=env)
-    } else {
-      stop("matrix expression should be 'name ~ c(lower-tri)'")
-    }
+    .fCall(x, env)
   } else {
     ## is.pairlist OR is.atomic OR unknown...
-    stop("bad matrix specification")
+    stop("bad matrix specification", call. = FALSE)
   }
 }
 ##' Parses condition
 ##'
 ##' @param cond Condition parsing tree
 ##' @param envir Environment to parse condition in.
-##' 
+##'
 ##' @return list with 2 elements: - First element is the name of the condition - Second element is extra information
 ##' @author Matthew Fidler
 ##' @noRd
-.parseCondition <- function(cond, envir=parent.frame()) {
+.parseCondition <- function(cond, envir = parent.frame()) {
   if (length(cond) == 1) {
     .fullCnd <- as.character(cond)
     return(list(.fullCnd, NULL))
   }
   .fullCnd <- as.character(cond[[1]])
-  if (regexpr("^[a-zA-Z][a-zA-Z0-9_.]*$", .fullCnd) == -1){
-    stop("unsupported conditional statement")
+  if (regexpr("^[a-zA-Z][a-zA-Z0-9_.]*$", .fullCnd) == -1) {
+    stop("unsupported conditional statement", call. = FALSE)
   }
-  .env  <- list2env(as.list(envir), parent=globalenv())
-  .env[[.fullCnd]] <- function(...){
+  .env <- list2env(as.list(envir), parent = globalenv())
+  .env[[.fullCnd]] <- function(...) {
     return(list(...))
   }
-  .prop <- eval(cond, envir=.env)
+  .prop <- eval(cond, envir = .env)
   return(list(.fullCnd, .prop))
 }
 
-.defaultProperties <- c(lower=-Inf, upper=Inf)
+.defaultProperties <- c(lower = -Inf, upper = Inf)
 
 ##' Amplify Default properties
 ##'
@@ -177,15 +204,17 @@ NULL
       .cur <- prop[[.n]]
       if (is.null(names(.cur))) {
         if (length(.cur) != 1) {
-          stop(sprintf("name multiple limits for '%s': '%s=c(%s=%s,...)'",
-                       .n, .n, names[1], .cur[1]))
+          stop(sprintf(
+            gettext("name multiple limits for '%s': '%s=c(%s=%s,...)'"),
+            .n, .n, names[1], .cur[1]
+          ), call. = FALSE)
         } else {
           .newProp[[.n]] <- setNames(rep(.cur, length(names)), names)
-          next;
+          next
         }
       }
       .new <- setNames(rep(.defaultProperties[.n], length(names)), names)
-      .bad <- c()
+      .bad <- NULL
       for (.n2 in names(.cur)) {
         if (is.na(.new[.n2])) {
           .bad <- c(.bad, .n2)
@@ -193,9 +222,11 @@ NULL
           .new[.n2] <- .cur[.n2]
         }
       }
-      if (length(.bad) > 0){
-        stop(sprintf("in '%s' argument/dimension mismatch: %s",
-                     .n, paste(.bad, collapse=", ")))
+      if (length(.bad) > 0) {
+        stop(sprintf(
+          gettext("in '%s' argument/dimension mismatch: %s"),
+          .n, paste(.bad, collapse = ", ")
+        ), call. = FALSE)
       }
       .newProp[[.n]] <- .new
     }
@@ -246,9 +277,13 @@ NULL
   if (!inherits(prop, "list")) {
     for (.n in names(new)) {
       if (any(.n == names(.defaultProperties))) {
-        new[[.n]] <- c(new[[.n]],
-                       setNames(rep(.defaultProperties[.n],
-                                    length(prop)), prop))
+        new[[.n]] <- c(
+          new[[.n]],
+          setNames(rep(
+            .defaultProperties[.n],
+            length(prop)
+          ), prop)
+        )
       }
     }
     .ret <- list()
@@ -262,7 +297,7 @@ NULL
       .old[[.n]] <- c(new[[.n]], .old[[.n]])
       new <- new[names(new) != .n]
     } else if (any(.n == names(new))) {
-      stop(sprintf("conflicting '%s' properties", .n))
+      stop(sprintf(gettext("conflicting '%s' properties"), .n), call. = FALSE)
     }
   }
   for (.n in names(new)) {
@@ -281,7 +316,68 @@ NULL
 ##' @author Matthew Fidler
 ##' @noRd
 .getMatrix <- function(env, val) {
-  return(.Call(`_lotriLstToMat`, env[[val]], NULL, 1L, PACKAGE='lotri'))
+  return(.Call(`_lotriLstToMat`, env[[val]], NULL, 1L, PACKAGE = "lotri"))
+}
+
+.lotriList <- function(x, ..., envir = parent.frame()) {
+  omega <- lapply(x, lotri, envir = envir)
+  if (inherits(omega, "list")) {
+    .env <- new.env(parent = emptyenv())
+    .env[["...cnd"]] <- NULL
+    .env[["...empty"]] <- list()
+    lapply(seq_along(omega), function(x) {
+      .cur <- omega[[x]]
+      .curName <- names(omega)[x]
+      if (is.null(.curName)) {
+        .curName <- ""
+      }
+      if (inherits(.cur, "matrix")) {
+        if (.curName == "") {
+          assign("...empty", c(.env[["...empty"]], list(.cur)), .env)
+        } else {
+          assign(.curName, c(.env[[.curName]], list(.cur)), .env)
+          assign("...cnd", unique(c(.env[["...cnd"]], .curName)), .env)
+        }
+      } else if (inherits(.cur, "list") || inherits(.cur, "lotri")) {
+        lapply(
+          seq_along(.cur),
+          function(y) {
+            .cury <- .cur[[y]]
+            .curName <- names(.cur)[y]
+            if (.curName == "") {
+              assign("...empty", c(
+                .env[["...empty"]],
+                list(.cury)
+              ), .env)
+            } else {
+              assign(.curName, list(.cury), .env)
+              assign("...cnd", unique(c(
+                .env[["...cnd"]],
+                .curName
+              )), .env)
+            }
+          }
+        )
+      }
+    })
+    if (length(.env$...empty) > 0) {
+      .omega <- .getMatrix(.env, "...empty")
+    } else {
+      .omega <- NULL
+    }
+    if (length(.env$...cnd) > 0) {
+      .lst <- setNames(lapply(.env$...cnd, function(cnd) {
+        .getMatrix(.env, cnd)
+      }), .env$...cnd)
+      if (!is.null(.omega)) {
+        .lst <- c(list(.omega), .lst)
+      }
+      omega <- .lst
+    } else {
+      omega <- .omega
+    }
+  }
+  omega
 }
 
 ##' Easily Specify block-diagonal matrices with lower triangular info
@@ -332,8 +428,8 @@ NULL
 ##'
 ##' lotri({et2 + et3 + et4 ~ c(40,
 ##'                            0.1, 20,
-##'                            0.1, 0.1, 30);
-##'           et5 ~ 6;
+##'                            0.1, 0.1, 30)
+##'           et5 ~ 6
 ##'           })
 ##'
 ##' ## You can also add lists or actual R matrices as in this example:
@@ -389,7 +485,7 @@ NULL
 ##' @importFrom stats setNames
 ##' @importFrom utils str
 ##' @export
-lotri  <- function(x, ..., envir=parent.frame()) {
+lotri <- function(x, ..., envir = parent.frame()) {
   .call <- as.list(match.call())[-1]
   .ncall <- names(.call)
   if (any(.ncall == "envir")) {
@@ -401,94 +497,43 @@ lotri  <- function(x, ..., envir=parent.frame()) {
   if (length(.call[[1]]) > 1) {
     if (identical(.call[[1]][[1]], quote(`|`))) {
       .cnd <- .call[[1]][[3]]
-      .fullCndLst <- .parseCondition(.cnd, envir=envir)
+      .fullCndLst <- .parseCondition(.cnd, envir = envir)
       .fullCnd <- .fullCndLst[[1]]
-      x <- eval(.call[[1]][[2]], envir=envir)
+      x <- eval(.call[[1]][[2]], envir = envir)
     }
   }
   if (is.null(x)) {
-    .ret  <- NULL
+    .ret <- NULL
   } else if (is.list(x)) {
-    omega  <- lapply(x, lotri, envir=envir)
-    if (inherits(omega, "list")) {
-      .env <- new.env(parent=emptyenv())
-      .env[["...cnd"]] <- c()
-      .env[["...empty"]] <- list()
-      lapply(seq_along(omega), function(x){
-        .cur <- omega[[x]]
-        .curName <- names(omega)[x]
-        if (is.null(.curName)) {
-          .curName <- ""
-        }
-        if (inherits(.cur, "matrix")) {
-          if (.curName == "") {
-            assign("...empty", c(.env[["...empty"]], list(.cur)), .env)
-          } else {
-            assign(.curName, c(.env[[.curName]], list(.cur)), .env)
-            assign("...cnd", unique(c(.env[["...cnd"]], .curName)), .env)
-          }
-        } else if (inherits(.cur, "list") || inherits(.cur, "lotri")) {
-          lapply(seq_along(.cur),
-                 function(y) {
-                   .cury <- .cur[[y]]
-                   .curName <- names(.cur)[y]
-                   if (.curName == "") {
-                     assign("...empty", c(.env[["...empty"]],
-                                          list(.cury)), .env)
-                   } else {
-                     assign(.curName, list(.cury), .env)
-                     assign("...cnd", unique(c(.env[["...cnd"]],
-                                               .curName)), .env)
-                   }
-                 })
-        }
-      })
-      if (length(.env$...empty) > 0){
-        .omega <- .getMatrix(.env, "...empty")
-      } else {
-        .omega <- NULL
-      }
-      if (length(.env$...cnd) > 0) {
-        .lst <- setNames(lapply(.env$...cnd, function(cnd) {
-          .getMatrix(.env, cnd)
-        }), .env$...cnd)
-        if (!is.null(.omega)) {
-          .lst <- c(list(.omega), .lst)
-        }
-        omega <- .lst
-      } else {
-        omega <- .omega
-      }
-    }
-    .ret  <- omega
+    .ret <- .lotriList(x, ..., envir = envir)
   } else if (is.matrix(x)) {
-    .ret  <- x
+    .ret <- x
   } else {
-    .env  <- new.env(parent=emptyenv())
-    .env$df  <- NULL
+    .env <- new.env(parent = emptyenv())
+    .env$df <- NULL
     .env$eta1 <- 0L
     .env$cnd <- character()
-    .sX  <- substitute(x)
+    .sX <- substitute(x)
     if (is.call(.sX)) {
       if (identical(.sX[[1]], quote(`[[`))) {
-        .sX  <- x
+        .sX <- x
       }
     }
     .f(.sX, .env)
     if (length(.env$cnd) == 0L) {
       .ret <- diag(.env$eta1)
       for (.i in seq_along(.env$df$i)) {
-        .ret[.env$df$i[.i], .env$df$j[.i]]  <- .env$df$x[.i]
+        .ret[.env$df$i[.i], .env$df$j[.i]] <- .env$df$x[.i]
       }
-      dimnames(.ret)  <- list(.env$names, .env$names)
+      dimnames(.ret) <- list(.env$names, .env$names)
     } else {
       .lstC <- list()
       .other <- NULL
       .prop <- NULL
       if (length(.call) > 1) {
         .call <- .call[-1]
-        .other <- do.call("lotri", .call, envir=envir)
-        if (inherits(.other, "lotri")){
+        .other <- do.call("lotri", .call, envir = envir)
+        if (inherits(.other, "lotri")) {
           .prop <- attr(.other, "lotri")
           class(.other) <- NULL
         }
@@ -497,9 +542,9 @@ lotri  <- function(x, ..., envir=parent.frame()) {
         .env2 <- .env[[.j]]
         .ret0 <- diag(.env2$eta1)
         for (.i in seq_along(.env2$df$i)) {
-          .ret0[.env2$df$i[.i], .env2$df$j[.i]]  <- .env2$df$x[.i]
+          .ret0[.env2$df$i[.i], .env2$df$j[.i]] <- .env2$df$x[.i]
         }
-        dimnames(.ret0)  <- list(.env2$names, .env2$names)
+        dimnames(.ret0) <- list(.env2$names, .env2$names)
         .extra <- .env[[paste0(.j, ".extra")]]
         if (!is.null(.extra)) {
           if (is.null(.prop)) {
@@ -507,14 +552,18 @@ lotri  <- function(x, ..., envir=parent.frame()) {
               .prop <- dimnames(.other[[.j]])[[1]]
             }
           }
-          .prop <- .mergeProp(.prop, .j,
-                              .amplifyDefault(.extra, .env2$names))
+          .prop <- .mergeProp(
+            .prop, .j,
+            .amplifyDefault(.extra, .env2$names)
+          )
         }
         if (inherits(.other, "list")) {
           if (any(names(.other) == .j)) {
             .ret0 <- do.call("lotri", list(.ret0, .other[[.j]],
-                                           envir=envir),
-                             envir=envir)
+              envir = envir
+            ),
+            envir = envir
+            )
             .other <- .other[names(.other) != .j]
           }
         }
@@ -539,8 +588,10 @@ lotri  <- function(x, ..., envir=parent.frame()) {
     .prop <- NULL
     if (!is.null(.fullCndLst[[2]])) {
       .prop <- list()
-      .prop[[.fullCnd]] <- .amplifyDefault(.fullCndLst[[2]],
-                                           dimnames(.ret)[[1]])
+      .prop[[.fullCnd]] <- .amplifyDefault(
+        .fullCndLst[[2]],
+        dimnames(.ret)[[1]]
+      )
     }
     if (!is.null(.prop)) {
       attr(.lst, "lotri") <- .amplifyFinal(.lst, .prop)
@@ -550,18 +601,22 @@ lotri  <- function(x, ..., envir=parent.frame()) {
       return(.lst)
     }
     .call <- .call[-1]
-    .tmp <- do.call("lotri", .call, envir=envir)
+    .tmp <- do.call("lotri", .call, envir = envir)
     if (any(names(.tmp) == .fullCnd)) {
       if (!is.null(.prop)) {
         .tmpL <- attr(.tmp, "lotri")
         .tmp0 <- .tmpL[[.fullCnd]]
         .tmp1 <- .tmpL[names(.tmpL) != .fullCnd]
-        .prop <- .mergeProp(.prop, .fullCnd,
-                            .amplifyDefault(.tmp0,
-                                            dimnames(.tmp[[.fullCnd]])[[1]]))
+        .prop <- .mergeProp(
+          .prop, .fullCnd,
+          .amplifyDefault(
+            .tmp0,
+            dimnames(.tmp[[.fullCnd]])[[1]]
+          )
+        )
         .prop <- c(.prop, .tmp1)
       }
-      .ret <- lotri(list(.ret, .tmp[[.fullCnd]]), envir=envir)
+      .ret <- lotri(list(.ret, .tmp[[.fullCnd]]), envir = envir)
       .w <- which(names(.tmp) != .fullCnd)
       if (length(.w) > 0L) {
         .tmp <- .tmp[.w]
@@ -590,21 +645,23 @@ lotri  <- function(x, ..., envir=parent.frame()) {
       return(.ret)
     }
   } else {
-    if (length(.call) == 1L) return(.ret)
+    if (length(.call) == 1L) {
+      return(.ret)
+    }
     .call <- .call[-1]
-    .tmp <- do.call("lotri", .call, envir=envir)
+    .tmp <- do.call("lotri", .call, envir = envir)
     if (inherits(.tmp, "list")) {
       if (any(names(.tmp) == "")) {
         .w <- which(names(.tmp) == "")
-        .lst <- list(.ret, .tmp[[.w]], envir=envir)
-        .tmp[[.w]] <- do.call("lotri", .lst, envir=envir)
+        .lst <- list(.ret, .tmp[[.w]], envir = envir)
+        .tmp[[.w]] <- do.call("lotri", .lst, envir = envir)
         return(.tmp)
       } else {
         .ret <- c(list(.ret), .tmp)
         return(.ret)
       }
     } else {
-      .ret <- lotri(c(list(.ret), list(.tmp)), envir=envir)
+      .ret <- lotri(c(list(.ret), list(.tmp)), envir = envir)
       if (inherits(.tmp, "lotri")) {
         attr(.ret, "lotri") <- .amplifyFinal(.ret, attr(.tmp, "lotri"))
         class(.ret) <- "lotri"
@@ -614,8 +671,8 @@ lotri  <- function(x, ..., envir=parent.frame()) {
   }
 }
 
-##'@export
-print.lotri <- function(x, ...){
+##' @export
+print.lotri <- function(x, ...) {
   .tmp <- x
   .lotri <- attr(.tmp, "lotri")
   class(.tmp) <- NULL
@@ -623,7 +680,7 @@ print.lotri <- function(x, ...){
   print(.tmp)
   .names <- x$.names
   if (length(.names) > 0) {
-    cat(paste0("Properties: ", paste(.names, collapse=", ")), "\n")
+    cat(paste0("Properties: ", paste(.names, collapse = ", ")), "\n")
   }
   return(invisible(x))
 }
@@ -633,62 +690,70 @@ str.lotri <- function(object, ...) {
   str(object$.list)
 }
 
-##'@importFrom utils .DollarNames
-##'@export
+##' @importFrom utils .DollarNames
+##' @export
 .DollarNames.lotri <- function(x, pattern) {
-  grep(pattern, unique(c(names(x), ".allNames", ".bounds",
-                         ".names", ".list", ".maxNu", x$.names)),
-       value=TRUE)
+  grep(pattern, unique(c(
+    names(x), ".allNames", ".bounds",
+    ".names", ".list", ".maxNu", x$.names
+  )),
+  value = TRUE
+  )
 }
 
-##'@export
-`$.lotri` <-  function(obj, arg, exact = FALSE) {
+##' @export
+`$.lotri` <- function(obj, arg, exact = FALSE) {
   .lotri <- attr(obj, "lotri")
   if (arg == ".maxNu") {
-    return(.Call(`_lotriMaxNu`, obj, PACKAGE="lotri"));
+    return(.Call(`_lotriMaxNu`, obj, PACKAGE = "lotri"))
   }
   if (any(names(obj) == arg)) {
     .tmp <- obj
     class(.tmp) <- NULL
     return(.tmp[[arg]])
   }
-  if (arg == ".names"){
-    return(unique(unlist(lapply(names(obj),
-                                function(x) {
-                                  names(.lotri[[x]])
-                                }))))
+  if (arg == ".names") {
+    return(unique(unlist(lapply(
+      names(obj),
+      function(x) {
+        names(.lotri[[x]])
+      }
+    ))))
   }
   if (arg == ".allNames") {
-    return(.Call(`_lotriAllNames`, obj ,PACKAGE="lotri"))
+    return(.Call(`_lotriAllNames`, obj, PACKAGE = "lotri"))
   }
   if (arg == ".bounds") {
-    return(.Call(`_lotriGetBounds`, obj, NULL, 1L, PACKAGE="lotri"))
+    return(.Call(`_lotriGetBounds`, obj, NULL, 1L, PACKAGE = "lotri"))
   }
   if (arg == ".list") {
     .tmp <- obj
     class(.tmp) <- NULL
     attr(.tmp, "lotri") <- NULL
     .names <- obj$.names
-    for (.n in .names){
-      if (!any(.n == names(.tmp)))
+    for (.n in .names) {
+      if (!any(.n == names(.tmp))) {
         .tmp[[.n]] <- `$.lotri`(obj, .n)
+      }
     }
     return(.tmp)
   }
-  
-  .env <- new.env(parent=emptyenv())
+
+  .env <- new.env(parent = emptyenv())
   .env$empty <- TRUE
   .ret <- setNames(lapply(names(obj), function(x) {
     if (any(names(.lotri) == x)) {
       .ret <- .lotri[[x]][[arg]]
-      if (is.null(.ret)) return(NULL)
+      if (is.null(.ret)) {
+        return(NULL)
+      }
       assign("empty", FALSE, .env)
       return(.ret)
     } else {
       .def <- .defaultProperties[arg]
       if (!is.na(.def)) {
         .w <- which(names(obj) == x)
-        if (length(.w) == 1){
+        if (length(.w) == 1) {
           .dim <- dimnames(obj[[.w]])[[1]]
           .ret <- setNames(rep(.def, length(.dim)), .dim)
           return(.ret)
@@ -729,19 +794,19 @@ str.lotri <- function(object, ...) {
 ##' @author Matthew Fidler
 ##'
 ##' @export
-as.lotri <- function(x, ..., default="") {
+as.lotri <- function(x, ..., default = "") {
   UseMethod("as.lotri")
 }
 
 ##' @rdname as.lotri
 ##' @export
-as.lotri.matrix <- function(x, ..., default="") {
-  .Call(`_asLotriMat`, x, list(...), default=default);
+as.lotri.matrix <- function(x, ..., default = "") {
+  .Call(`_asLotriMat`, x, list(...), default = default)
 }
 
 ##' @rdname as.lotri
 ##' @export
-as.lotri.default <- function(x, ..., default="") {
+as.lotri.default <- function(x, ..., default = "") {
   .ret <- x
   class(.ret) <- NULL
   .n <- names(.ret)
@@ -754,21 +819,21 @@ as.lotri.default <- function(x, ..., default="") {
   return(.ret)
 }
 
-##'@export
-as.matrix.lotri <- function(x, ...){
+##' @export
+as.matrix.lotri <- function(x, ...) {
   .ret <- x
   class(.ret) <- NULL
-  if (length(.ret) == 1){
+  if (length(.ret) == 1) {
     return(.ret[[1]])
   } else {
-    stop("cannot convert multiple level lotri matrix to simple matrix")
+    stop("cannot convert multiple level lotri matrix to simple matrix", call. = FALSE)
   }
 }
 ##' Create a matrix from a list of matrices
 ##'
 ##' This creates a named banded symmetric matrix from a list of named
 ##' symmetric matrices.
-##' 
+##'
 ##' @param matList list of symmetric named matrices
 ##'
 ##' @param format The format of dimension names when a sub-matrix is
@@ -780,7 +845,7 @@ as.matrix.lotri <- function(x, ...){
 ##'
 ##' @return Named symmetric block diagonal matrix based on
 ##'   concatenating the list of matrices together
-##' 
+##'
 ##' @examples
 ##'
 ##' testList <- list(lotri({et2 + et3 + et4 ~ c(40,
@@ -813,20 +878,20 @@ as.matrix.lotri <- function(x, ...){
 ##' lotriMat(testList, "ETA[%d]")
 ##'
 ##' # Or could start with ETA[2]:
-##' 
+##'
 ##' lotriMat(testList, "ETA[%d]", 2)
-##' 
+##'
 ##' @author Matthew Fidler
 ##' @export
-lotriMat <- function(matList, format=NULL, start=1L) {
-  .Call(`_lotriLstToMat`, matList, format, start, PACKAGE='lotri')
+lotriMat <- function(matList, format = NULL, start = 1L) {
+  .Call(`_lotriLstToMat`, matList, format, start, PACKAGE = "lotri")
 }
 
 ##' Separate a lotri matrix into above and below lotri matrices
 ##'
 ##' This is used for creating nesting simulations in `RxODE` and may
 ##' not be useful for external function calls.
-##' 
+##'
 ##' @param x lotri matrix
 ##' @param above Named integer vector listing variability above the id
 ##'   level.  Each element lists the number of population differences
@@ -852,8 +917,9 @@ lotriMat <- function(matList, format=NULL, start=1L) {
 ##'
 ##' lotriSep(omega, above=c(inv=10L), below=c(eye=2L, occ=4L))
 lotriSep <- function(x, above, below,
-                     aboveStart=1L, belowStart=1L){
+                     aboveStart = 1L, belowStart = 1L) {
   .Call(`_lotriSep`, x, above, below,
-        aboveStart=as.integer(aboveStart), belowStart=as.integer(belowStart),
-        PACKAGE="lotri")
+    aboveStart = as.integer(aboveStart), belowStart = as.integer(belowStart),
+    PACKAGE = "lotri"
+  )
 }
